package com.fs.company.mapper;

import java.util.List;
import com.fs.company.domain.CompanyPurchase;

/**
 * 采购Mapper接口
 * 
 * @author fs
 * @date 2025-07-01
 */
public interface CompanyPurchaseMapper 
{
    /**
     * 查询采购
     * 
     * @param id 采购主键
     * @return 采购
     */
    public CompanyPurchase selectCompanyPurchaseById(Long id);

    /**
     * 查询采购列表
     * 
     * @param companyPurchase 采购
     * @return 采购集合
     */
    public List<CompanyPurchase> selectCompanyPurchaseList(CompanyPurchase companyPurchase);

    /**
     * 新增采购
     * 
     * @param companyPurchase 采购
     * @return 结果
     */
    public int insertCompanyPurchase(CompanyPurchase companyPurchase);

    /**
     * 修改采购
     * 
     * @param companyPurchase 采购
     * @return 结果
     */
    public int updateCompanyPurchase(CompanyPurchase companyPurchase);

    /**
     * 删除采购
     * 
     * @param id 采购主键
     * @return 结果
     */
    public int deleteCompanyPurchaseById(Long id);

    /**
     * 批量删除采购
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteCompanyPurchaseByIds(Long[] ids);
}
